<?php
/**
* The template for adding additional theme options in Customizer
*
* @package Catch Themes
* @subpackage Rock Star Pro
* @since Rock Star 1.0
*/

$wp_customize->add_panel( 'rock_star_theme_options', array(
    'description'    => esc_html__( 'Basic theme Options', 'rock-star-pro' ),
    'capability'     => 'edit_theme_options',
    'priority'       => 200,
    'title'    		 => esc_html__( 'Theme Options', 'rock-star-pro' ),
) );

// Loader Options
$wp_customize->add_section( 'rock_star_preloader_image', array(
	'description'	=> esc_html__( 'Preloader image is the image that loads beforehand while the main page loads', 'rock-star-pro' ),
	'panel'			=> 'rock_star_theme_options',
	'title'    		=> esc_html__( 'Preloader Image', 'rock-star-pro' ),
	'priority' 		=> 201,
) );

$wp_customize->add_setting( 'rock_star_theme_options[enable_preloader]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['enable_preloader'],
	'sanitize_callback' => 'rock_star_sanitize_checkbox'
) );

$wp_customize->add_control( 'rock_star_theme_options[enable_preloader]', array(
	'label'    => esc_html__( 'Check to enable Preloader Image', 'rock-star-pro' ),
	'section'  => 'rock_star_preloader_image',
	'settings' => 'rock_star_theme_options[enable_preloader]',
	'type'     => 'checkbox',
) );

$wp_customize->add_setting( 'rock_star_theme_options[preloader_image]', array(
	'capability'        => 'edit_theme_options',
	'default'			=> $defaults['preloader_image'],
	'sanitize_callback' => 'rock_star_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'rock_star_theme_options[preloader_image]', array(
	'label'       => esc_html__( 'Preloader Image', 'rock-star-pro' ),
	'section'     => 'rock_star_preloader_image',
	'settings'    => 'rock_star_theme_options[preloader_image]',
) ) );

// Breadcrumb Option
$wp_customize->add_section( 'rock_star_breadcrumb_options', array(
	'description'	=> esc_html__( 'Breadcrumbs are a great way of letting your visitors find out where they are on your site with just a glance. You can enable/disable them on homepage and entire site.', 'rock-star-pro' ),
	'panel'			=> 'rock_star_theme_options',
	'title'    		=> esc_html__( 'Breadcrumb Options', 'rock-star-pro' ),
	'priority' 		=> 201,
) );

$wp_customize->add_setting( 'rock_star_theme_options[breadcrumb_option]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['breadcrumb_option'],
	'sanitize_callback' => 'rock_star_sanitize_checkbox'
) );

$wp_customize->add_control( 'rock_star_theme_options[breadcrumb_option]', array(
	'label'    => esc_html__( 'Check to enable Breadcrumb', 'rock-star-pro' ),
	'section'  => 'rock_star_breadcrumb_options',
	'settings' => 'rock_star_theme_options[breadcrumb_option]',
	'type'     => 'checkbox',
) );

$wp_customize->add_setting( 'rock_star_theme_options[$breadcrumb_on_homepage]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['$breadcrumb_on_homepage'],
	'sanitize_callback' => 'rock_star_sanitize_checkbox'
) );

$wp_customize->add_control( 'rock_star_theme_options[$breadcrumb_on_homepage]', array(
	'label'    => esc_html__( 'Check to enable Breadcrumb on Homepage', 'rock-star-pro' ),
	'section'  => 'rock_star_breadcrumb_options',
	'settings' => 'rock_star_theme_options[$breadcrumb_on_homepage]',
	'type'     => 'checkbox',
) );

$wp_customize->add_setting( 'rock_star_theme_options[breadcrumb_seperator]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['breadcrumb_seperator'],
	'sanitize_callback'	=> 'sanitize_text_field',
) );

$wp_customize->add_control( 'rock_star_theme_options[breadcrumb_seperator]', array(
	'input_attrs' => array(
    		'style' => 'width: 40px;'
		),
	'label'    	=> esc_html__( 'Separator between Breadcrumbs', 'rock-star-pro' ),
	'section' 	=> 'rock_star_breadcrumb_options',
	'settings' 	=> 'rock_star_theme_options[breadcrumb_seperator]',
	'type'     	=> 'text'
	)
);
	// Breadcrumb Option End

	// Comment Option
$wp_customize->add_section( 'rock_star_comment_option', array(
	'description'	=> esc_html__( 'Comments can also be disabled on a per post/page basis when creating/editing posts/pages.', 'rock-star-pro' ),
	'panel' 		=> 'rock_star_theme_options',
	'priority'		=> 202,
	'title'   		=> esc_html__( 'Comment Options', 'rock-star-pro' ),
) );

$wp_customize->add_setting( 'rock_star_theme_options[comment_option]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['comment_option'],
	'sanitize_callback' => 'rock_star_sanitize_select',
) );

$wp_customize->add_control( 'rock_star_theme_options[comment_option]', array(
		'choices'  	=> rock_star_comment_options(),
		'label'		=> esc_html__( 'Comment Option', 'rock-star-pro' ),
        'priority'	=> 1,
		'section'   => 'rock_star_comment_option',
        'settings'  => 'rock_star_theme_options[comment_option]',
        'type'	  	=> 'select',
) );

$wp_customize->add_setting( 'rock_star_theme_options[disable_notes]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['disable_notes'],
	'sanitize_callback' => 'rock_star_sanitize_checkbox',
) );

$wp_customize->add_control( 'rock_star_theme_options[disable_notes]', array(
	'label'		=> esc_html__( 'Check to Disable Notes', 'rock-star-pro' ),
	'section'   => 'rock_star_comment_option',
    'settings'  => 'rock_star_theme_options[disable_notes]',
	'type'		=> 'checkbox',
) );

$wp_customize->add_setting( 'rock_star_theme_options[disable_website_field]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['disable_website_field'],
	'sanitize_callback' => 'rock_star_sanitize_checkbox',
) );

$wp_customize->add_control( 'rock_star_theme_options[disable_website_field]', array(
	'label'		=> esc_html__( 'Check to Disable Website Field', 'rock-star-pro' ),
	'section'   => 'rock_star_comment_option',
    'settings'  => 'rock_star_theme_options[disable_website_field]',
	'type'		=> 'checkbox',
) );
	// Comment End

/**
 * Remove Custom CSS option from WordPress 4.7 onwards
 */
if ( !function_exists( 'wp_update_custom_css_post' ) ) {
	// Custom CSS Option
	$wp_customize->add_section( 'rock_star_custom_css', array(
		'description'	=> esc_html__( 'Custom/Inline CSS', 'rock-star-pro'),
		'panel'  		=> 'rock_star_theme_options',
		'priority' 		=> 203,
		'title'    		=> esc_html__( 'Custom CSS Options', 'rock-star-pro' ),
	) );

	$wp_customize->add_setting( 'rock_star_theme_options[custom_css]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['custom_css'],
		'sanitize_callback' => 'rock_star_sanitize_custom_css',
	) );

	$wp_customize->add_control( 'rock_star_theme_options[custom_css]', array(
			'label'		=> esc_html__( 'Enter Custom CSS', 'rock-star-pro' ),
	        'priority'	=> 1,
			'section'   => 'rock_star_custom_css',
	        'settings'  => 'rock_star_theme_options[custom_css]',
			'type'		=> 'textarea',
	) );
	// Custom CSS End
}

	// Excerpt Options
$wp_customize->add_section( 'rock_star_excerpt_options', array(
	'panel'  	=> 'rock_star_theme_options',
	'priority' 	=> 204,
	'title'    	=> esc_html__( 'Excerpt Options', 'rock-star-pro' ),
) );

$wp_customize->add_setting( 'rock_star_theme_options[excerpt_length]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['excerpt_length'],
	'sanitize_callback' => 'absint',
) );

$wp_customize->add_control( 'rock_star_theme_options[excerpt_length]', array(
	'description' => __('Excerpt length. Default is 30 words', 'rock-star-pro'),
	'input_attrs' => array(
        'min'   => 10,
        'max'   => 200,
        'step'  => 5,
        'style' => 'width: 60px;'
        ),
    'label'    => esc_html__( 'Excerpt Length (words)', 'rock-star-pro' ),
	'section'  => 'rock_star_excerpt_options',
	'settings' => 'rock_star_theme_options[excerpt_length]',
	'type'	   => 'number',
	)
);

$wp_customize->add_setting( 'rock_star_theme_options[excerpt_more_text]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['excerpt_more_text'],
	'sanitize_callback'	=> 'sanitize_text_field',
) );

$wp_customize->add_control( 'rock_star_theme_options[excerpt_more_text]', array(
	'label'    => esc_html__( 'Read More Text', 'rock-star-pro' ),
	'section'  => 'rock_star_excerpt_options',
	'settings' => 'rock_star_theme_options[excerpt_more_text]',
	'type'	   => 'text',
) );
// Excerpt Options End

// Feed Redirect
$wp_customize->add_section( 'rock_star_feed_redirect', array(
	'panel'			=> 'rock_star_theme_options',
	'description'	=> esc_html__( 'If your custom feed(s) are not handled by Feedblitz or Feedburner, do not use the redirect options.', 'rock-star-pro' ),
	'title'    		=> esc_html__( 'Feed Redirect', 'rock-star-pro' ),
	'priority' 		=> 218,
) );

$wp_customize->add_setting( 'rock_star_theme_options[feed_redirect]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['feed_redirect'],
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'rock_star_theme_options[feed_redirect]', array(
	'label'    => esc_html__( 'Feed Redirect', 'rock-star-pro' ),
	'section'  => 'rock_star_feed_redirect',
	'settings' => 'rock_star_theme_options[feed_redirect]',
	'type'	   => 'text',
) );
// Feed Redirect End

// Font Family Options
$wp_customize->add_section( 'rock_star_font_family', array(
	'panel'  => 'rock_star_theme_options',
	'priority'	=> 206,
	'title'    	=> esc_html__( 'Font Family Options', 'rock-star-pro' ),
) );

$avaliable_fonts = rock_star_avaliable_fonts();

$choices = array();

foreach ( $avaliable_fonts as $avaliable_font ) {
	$choices[ $avaliable_font[ 'value' ] ] = str_replace( '"', '', $avaliable_font[ 'label' ] );
}

$font_family_options	=	array(
	'title_font' 		=> esc_html__( 'Site Title Font Family', 'rock-star-pro' ),
	'body_font' 		=> esc_html__( 'Default Font Family', 'rock-star-pro' ),
	'tagline_font' 		=> esc_html__( 'Site Tagline Font Family', 'rock-star-pro' ),
	'menu_font' 		=> esc_html__( 'Menu Font Family', 'rock-star-pro' ),
	'content_title_font'=> esc_html__( 'Content Title Font Family', 'rock-star-pro' ),
	'content_font' 		=> esc_html__( 'Content Body Font Family', 'rock-star-pro' ),
	'headings_font' 	=> esc_html__( 'Headings Tags from h1 to h6 Font Family', 'rock-star-pro' )
);

foreach ( $font_family_options as $key => $font_family_option ) {
	$wp_customize->add_setting( 'rock_star_theme_options['. $key . ']', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults[ $key ],
		'sanitize_callback' => 'rock_star_sanitize_select',
	) );

	$wp_customize->add_control( 'rock_star_theme_options['. $key . ']', array(
		'choices'  => $choices,
		'label'    => $font_family_option,
		'section'  => 'rock_star_font_family',
		'settings' => 'rock_star_theme_options['. $key . ']',
		'type'	   => 'select',
	) );
}

$wp_customize->add_setting( 'rock_star_theme_options[reset_typography]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['reset_typography'],
	'sanitize_callback' => 'rock_star_sanitize_checkbox',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'rock_star_theme_options[reset_typography]', array(
	'label'		=> esc_html__( 'Check to reset fonts', 'rock-star-pro' ),
	'section'	=> 'rock_star_font_family',
	'settings'	=> 'rock_star_theme_options[reset_typography]',
	'type'		=> 'checkbox',
) );
// Font Family Options End

// Footer Editor Options
$wp_customize->add_section( 'rock_star_footer_options', array(
	'description' => esc_html__( 'You can either add html or plain text', 'rock-star-pro'),
	'panel'       => 'rock_star_theme_options',
	'priority'    => 207,
	'title'       => esc_html__( 'Footer Editor Options', 'rock-star-pro' ),
) );

$wp_customize->add_setting( 'rock_star_theme_options[footer_content]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['footer_content'],
	'sanitize_callback'	=> 'rock_star_sanitize_footer_code',
) );

$wp_customize->add_control( 'rock_star_theme_options[footer_content]', array(
	'description' => esc_html__( 'You can add custom shortcodes, which will be automatically inserted into your theme. Some shorcodes: [the-year], [site-link] and [privacy-policy-link] for current year, site link and privacy policy link respectively.', 'rock-star-pro' ),
	'label'       => esc_html__( 'Footer Content', 'rock-star-pro' ),
	'priority'    => 1,
	'section'     => 'rock_star_footer_options',
	'settings'    => 'rock_star_theme_options[footer_content]',
	'type'        => 'textarea',
) );

$wp_customize->add_setting( 'rock_star_theme_options[reset_footer_content]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['reset_footer_content'],
	'sanitize_callback' => 'rock_star_sanitize_checkbox',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'rock_star_theme_options[reset_footer_content]', array(
	'label'		=> esc_html__( 'Check to reset Footer Content', 'rock-star-pro' ),
	'priority'	=> 3,
	'settings'	=> 'rock_star_theme_options[reset_footer_content]',
	'section'	=> 'rock_star_footer_options',
	'type'		=> 'checkbox',
) );
// Footer Options End

//Homepage / Frontpage Options
$wp_customize->add_section( 'rock_star_homepage_options', array(
	'description'	=> esc_html__( 'Only posts that belong to the categories selected here will be displayed on the front page', 'rock-star-pro' ),
	'panel'			=> 'rock_star_theme_options',
	'title'   	 	=> esc_html__( 'Homepage / Frontpage Options', 'rock-star-pro' ),
	'priority' 		=> 208,
) );

$wp_customize->add_setting( 'rock_star_theme_options[latest_posts_title]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['latest_posts_title'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'rock_star_theme_options[latest_posts_title]', array(
	'label'		=> esc_html__( 'Latest Posts Title', 'rock-star-pro' ),
	'section'   => 'rock_star_homepage_options',
    'settings'  => 'rock_star_theme_options[latest_posts_title]',
	'type'		=> 'text',
) );

$wp_customize->add_setting( 'rock_star_theme_options[front_page_category]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['front_page_category'],
	'sanitize_callback'	=> 'rock_star_sanitize_category_list',
) );

$wp_customize->add_control( new rock_star_customize_dropdown_categories_control( $wp_customize, 'rock_star_theme_options[front_page_category]', array(
    'label'   	=> esc_html__( 'Select Categories', 'rock-star-pro' ),
    'name'	 	=> 'rock_star_theme_options[front_page_category]',
	'section'  	=> 'rock_star_homepage_options',
    'settings' 	=> 'rock_star_theme_options[front_page_category]',
    'type'     	=> 'dropdown-categories',
) ) );
//Homepage / Frontpage Settings End

// Layout Options
$wp_customize->add_section( 'rock_star_layout', array(
	'capability'=> 'edit_theme_options',
	'panel'		=> 'rock_star_theme_options',
	'priority'	=> 211,
	'title'		=> esc_html__( 'Layout Options', 'rock-star-pro' ),
) );

$wp_customize->add_setting( 'rock_star_theme_options[theme_layout]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['theme_layout'],
	'sanitize_callback' => 'rock_star_sanitize_select',
) );

$wp_customize->add_control( 'rock_star_theme_options[theme_layout]', array(
	'choices'  => rock_star_layouts(),
	'label'    => esc_html__( 'Default Layout', 'rock-star-pro' ),
	'section'  => 'rock_star_layout',
	'settings' => 'rock_star_theme_options[theme_layout]',
	'type'     => 'select',
) );

if ( class_exists( 'WooCommerce' ) ) {
	$wp_customize->add_setting( 'rock_star_theme_options[woocommerce_layout]', array(
		'capability'        => 'edit_theme_options',
		'default'           => $defaults['woocommerce_layout'],
		'sanitize_callback' => 'rock_star_sanitize_select',
	) );

	$wp_customize->add_control( 'rock_star_theme_options[woocommerce_layout]', array(
		'choices'  => rock_star_layouts(),
		'label'    => esc_html__( 'Woocommerce Layout', 'rock-star-pro' ),
		'section'  => 'rock_star_layout',
		'settings' => 'rock_star_theme_options[woocommerce_layout]',
		'type'     => 'select',
	) );
}

$wp_customize->add_setting( 'rock_star_theme_options[single_page_post_layout]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['single_page_post_layout'],
	'sanitize_callback' => 'rock_star_sanitize_select',
) );

$wp_customize->add_control( 'rock_star_theme_options[single_page_post_layout]', array(
	'choices'  => rock_star_layouts(),
	'label'    => esc_html__( 'Single Page/Post Layout', 'rock-star-pro' ),
	'section'  => 'rock_star_layout',
	'settings' => 'rock_star_theme_options[single_page_post_layout]',
	'type'     => 'select',
) );

$wp_customize->add_setting( 'rock_star_theme_options[content_layout]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['content_layout'],
	'sanitize_callback' => 'rock_star_sanitize_select',
) );

$wp_customize->add_control( 'rock_star_theme_options[content_layout]', array(
	'choices'   => rock_star_get_archive_content_layout(),
	'label'		=> esc_html__( 'Archive Content Layout', 'rock-star-pro' ),
	'section'   => 'rock_star_layout',
	'settings'  => 'rock_star_theme_options[content_layout]',
	'type'      => 'select',
) );

$wp_customize->add_setting( 'rock_star_theme_options[archive_top_layout]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['archive_top_layout'],
	'sanitize_callback' => 'rock_star_sanitize_select',
) );

$wp_customize->add_control( 'rock_star_theme_options[archive_top_layout]', array(
	'active_callback' => 'rock_star_is_layout_excerpt_image_top',
	'choices'         => rock_star_featured_content_layout_options(),
	'label'           => esc_html__( 'Excerpt Image Top Layout', 'rock-star-pro' ),
	'section'         => 'rock_star_layout',
	'settings'        => 'rock_star_theme_options[archive_top_layout]',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'rock_star_theme_options[single_post_image_size]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['single_post_image_size'],
	'sanitize_callback' => 'rock_star_sanitize_select',
) );

$wp_customize->add_control( 'rock_star_theme_options[single_post_image_size]', array(
		'label'		=> esc_html__( 'Single Page/Post Image Size ', 'rock-star-pro' ),
		'section'   => 'rock_star_layout',
        'settings'  => 'rock_star_theme_options[single_post_image_size]',
        'type'	  	=> 'select',
		'choices'  	=> rock_star_single_post_image_size_options(),
) );
	// Layout Options End

// Pagination Options
$pagination_type	= $options['pagination_type'];

$navigation_description = sprintf(
	wp_kses(
		__( '<a target="_blank" href="%1$s">WP-PageNavi Plugin</a> is recommended for Numeric Option(But will work without it).<br/>Infinite Scroll Options requires <a target="_blank" href="%2$s">JetPack Plugin</a> with Infinite Scroll module Enabled.', 'rock-star-pro' ),
		array(
			'a' => array(
				'href' => array(),
				'target' => array(),
			),
			'br'=> array()
		)
	),
	esc_url( 'https://wordpress.org/plugins/wp-pagenavi' ),
	esc_url( 'https://wordpress.org/plugins/jetpack/' )
);

/**
* Check if navigation type is Jetpack Infinite Scroll and if it is enabled
*/
if ( ( 'infinite-scroll-click' == $pagination_type || 'infinite-scroll-scroll' == $pagination_type ) ) {
	if ( ! (class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'infinite-scroll' ) ) ) {
		$navigation_description = sprintf(
			wp_kses(
				__( 'Infinite Scroll Options requires <a target="_blank" href="%s">JetPack Plugin</a> with Infinite Scroll module Enabled.', 'rock-star-pro' ),
				array(
					'a' => array(
						'href' => array(),
						'target' => array()
					)
				)
			),
			esc_url( 'https://wordpress.org/plugins/jetpack/' )
		);
	}
	else {
		$navigation_description = '';
	}
}

$wp_customize->add_section( 'rock_star_pagination_options', array(
	'description'	=> $navigation_description,
	'panel'  		=> 'rock_star_theme_options',
	'priority'		=> 212,
	'title'    		=> esc_html__( 'Pagination Options', 'rock-star-pro' ),
) );

$wp_customize->add_setting( 'rock_star_theme_options[pagination_type]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['pagination_type'],
	'sanitize_callback' => 'sanitize_key',
) );

$wp_customize->add_control( 'rock_star_theme_options[pagination_type]', array(
	'choices'  => rock_star_get_pagination_types(),
	'label'    => esc_html__( 'Pagination type', 'rock-star-pro' ),
	'section'  => 'rock_star_pagination_options',
	'settings' => 'rock_star_theme_options[pagination_type]',
	'type'	   => 'select',
) );
// Pagination Options End

// Scrollup
$wp_customize->add_section( 'rock_star_scrollup', array(
	'panel'    => 'rock_star_theme_options',
	'priority' => 215,
	'title'    => esc_html__( 'Scrollup Options', 'rock-star-pro' ),
) );

$wp_customize->add_setting( 'rock_star_theme_options[disable_scrollup]', array(
	'capability'		=> 'edit_theme_options',
    'default'			=> $defaults['disable_scrollup'],
	'sanitize_callback' => 'rock_star_sanitize_checkbox',
) );

$wp_customize->add_control( 'rock_star_theme_options[disable_scrollup]', array(
	'label'		=> esc_html__( 'Check to disable Scroll Up', 'rock-star-pro' ),
	'section'   => 'rock_star_scrollup',
    'settings'  => 'rock_star_theme_options[disable_scrollup]',
	'type'		=> 'checkbox',
) );
// Scrollup End

// Search Options
$wp_customize->add_section( 'rock_star_search_options', array(
	'description'=> esc_html__( 'Change default placeholder text in Search.', 'rock-star-pro'),
	'panel'  => 'rock_star_theme_options',
	'priority' => 216,
	'title'    => esc_html__( 'Search Options', 'rock-star-pro' ),
) );

$wp_customize->add_setting( 'rock_star_theme_options[search_text]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['search_text'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'rock_star_theme_options[search_text]', array(
	'label'		=> esc_html__( 'Default Display Text in Search', 'rock-star-pro' ),
	'section'   => 'rock_star_search_options',
    'settings'  => 'rock_star_theme_options[search_text]',
	'type'		=> 'text',
) );
// Search Options End

// Single Post Navigation
$wp_customize->add_section( 'rock_star_single_post_navigation', array(
	'panel'  => 'rock_star_theme_options',
	'priority' => 217,
	'title'    => esc_html__( 'Single Post Navigation', 'rock-star-pro' ),
) );

$wp_customize->add_setting( 'rock_star_theme_options[disable_single_post_navigation]', array(
	'capability'		=> 'edit_theme_options',
    'default'			=> $defaults['disable_single_post_navigation'],
	'sanitize_callback' => 'rock_star_sanitize_checkbox',
) );

$wp_customize->add_control( 'rock_star_theme_options[disable_single_post_navigation]', array(
	'label'		=> esc_html__( 'Check to disable Single Post Navigation', 'rock-star-pro' ),
	'section'   => 'rock_star_single_post_navigation',
    'settings'  => 'rock_star_theme_options[disable_single_post_navigation]',
	'type'		=> 'checkbox',
) );
// Single Post Navigation End

// Update Notifier
$wp_customize->add_section( 'rock_star_update_notifier', array(
	'title'    => esc_html__( 'Update Notifier', 'rock-star-pro' ),
	'priority' => 219,
	'panel'    => 'rock_star_theme_options',
) );

$wp_customize->add_setting( 'rock_star_theme_options[update_notifier]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['update_notifier'],
	'sanitize_callback' => 'rock_star_sanitize_checkbox',
) );

$wp_customize->add_control( 'rock_star_theme_options[update_notifier]', array(
	'label'		=> esc_html__( 'Check to disable update notifications', 'rock-star-pro' ),
	'section'   => 'rock_star_update_notifier',
    'settings'  => 'rock_star_theme_options[update_notifier]',
	'type'		=> 'checkbox',
) );
// Update Notifier End