<?php
/**
 * The template for displaying Social Icons
 *
 * @package Catch Themes
 * @subpackage Rock Star Pro
 * @since Rock Star 1.0
 */

if ( ! function_exists( 'rock_star_get_social_icons' ) ) :
/**
 * Generate social icons.
 *
 * @since Rock Star 1.0
 */
function rock_star_get_social_icons(){
	if ( ( !$output = get_transient( 'rock_star_social_icons' ) ) ) {
		$output	= '<ul class="social-icons">';

		$options 	= rock_star_get_theme_options(); // Get options

		//Pre defined Social Icons Link Start
		$pre_def_social_icons 	=	rock_star_get_social_icons_list();

		foreach ( $pre_def_social_icons as $key => $item ) {
			if ( isset( $options[ $key ] ) && '' != $options[ $key ] ) {
				$value = $options[ $key ];

				if ( 'email_link' == $key  ) {
					$output .= '
						<li>
							<a target="_blank" title="'. esc_attr__( 'Email', 'rock-star-pro') .'" href=" mailto:'. antispambot( sanitize_email( $value ) ) .'" class="icon-animation icon-hover-effect">
								<div class="genericon icon-hover genericon-'. sanitize_key( $item['genericon_class'] ) .' " >
									<span class="screen-reader-text">'. esc_html__( 'Email', 'rock-star-pro') .'</span>
								</div>
							</a>
						</li>
						';
				}
				elseif ( 'skype_link' == $key  ) {
					$output .= '
					<li>
						<a target="_blank" title="'. esc_attr( $item['label'] ) .'" href="'. esc_attr( $value ) .'" class="icon-animation icon-hover-effect">
							<div class="genericon icon-hover genericon-'. sanitize_key( $item['label'] ) .' " >
								<span class="screen-reader-text">'. esc_attr( $item['label'] ) .'</span>
							</div>
						</a>
					</li>
					';
				}
				elseif ( 'phone_link' == $key || 'handset_link' == $key ) {
					$output .= '
					<li>
						<a target="_blank" title="'. esc_attr( $item['label'] ) .'" href="tel:' . preg_replace( '/\s+/', '', esc_attr( $value ) ) . '" class="icon-animation icon-hover-effect">
							<div class="genericon icon-hover genericon-'. sanitize_key( $item['genericon_class'] ) .' " >
								<span class="screen-reader-text">'. esc_attr( $item['label'] ) .'</span>
							</div>
						</a>
					</li>
					';
				}
				else {
					$output .= '
						<li>
							<a target="_blank" title="'. esc_attr( $item['label'] ) .'" href="'. esc_url( $value ) .'" class="icon-animation icon-hover-effect">
								<div class="genericon icon-hover genericon-'. sanitize_key( $item['genericon_class'] ) .' " >
									<span class="screen-reader-text">'. esc_attr( $item['label'] ) .'</span>
								</div>
							</a>
						</li>
						';
				}
			}
		}
		//Pre defined Social Icons Link End

		//Custom Social Icons Link Start
		for( $i = 1; $i <= $options['custom_social_icons'] ; $i++ ) {
			$has_hover 		= '';
			$image_hover 	= '';

			if ( ! empty( $options['custom_social_icon_image_'. $i] ) ) {
				$image = $options['custom_social_icon_image_'. $i];

				if ( ! empty( $options['custom_social_icon_image_hover_'. $i] ) ) {
					$image_hover = $options['custom_social_icon_image_hover_'. $i];
					$has_hover = " has-hover";
				}

				//Checking Link
				if ( ! empty( $options['custom_social_icon_link_'. $i] ) ) {
					$link = $options['custom_social_icon_link_'. $i];
				} else {
					$link = '#';
				}

				//Checking Title
				if ( !empty ( $options['custom_social_icon_title_'. $i]) ) {
					$title = $options['custom_social_icon_title_'. $i];
				} else {
					$title = '';
				}

				//Custom Social Icons
				$output .= '<li><a id="custom-icon-'. $i .'" class="custom-icon' . $has_hover . '" target="_blank" title="' . esc_attr( $title ) . '" href="' . esc_url( $link ) . '">
					<img  alt="' . esc_attr( $title ) . '" class ="icon-static" src="' . esc_url( $image ) . '" />';

					if (isset ( $image_hover ) && '' != $image_hover ) {
					$output .= '<img  alt="' . esc_attr( $title ) . '" class ="icon-hover" src="' . esc_url( $image_hover ) . '" />';
				}
				$output .= '</a></li>';
			}
		}
		$output .= '</ul><!-- end social-ions -->';
		//Custom Social Icons Link End
		set_transient( 'rock_star_social_icons', $output, 86940 );
	}
	return $output;
} // rock_star_get_social_icons
endif;