<?php
/**
 * Featured Post Widget
 *
 * @package Catch Themes
 * @subpackage Rock Star Pro
 * @since Rock Star 1.0
 */

/**
 * Featured Post widget class
 *
 * @since Rock Star 1.0
 */
class rock_star_video_post_page_widget extends WP_Widget {

	/**
	 * Holds widget settings defaults, populated in constructor.
	 *
	 * @var array
	 */
	protected $defaults;

	function __construct() {

		$this->defaults = array(
			'title'            => '',
			'description'      => '',
			'post_type'        => 'all-categories',
			'post_id'          => '',
			'category'         => array(),
			'post_number'      => 3,
			'background-image' => '',
			'layout'           => 'video-grid-layout',
			'link'             => '',
			'link_text'        => '',
			'target'           => 1
		);

		$widget_ops = array(
			'classname'   => 'ct-video-post ctvideopostpageimage',
			'description' => esc_html__( 'Displays video posts/pages', 'rock-star-pro' ),
		);

		$control_ops = array(
			'id_base' => 'ct-video-post',
		);

		parent::__construct(
			'ct-video-post', // Base ID
			__( 'CT: Video Pages & Posts', 'rock-star-pro' ), // Name
			$widget_ops,
			$control_ops
		);
	}

	function form( $instance ) {

		//* Merge with defaults
		$instance = wp_parse_args( (array) $instance, $this->defaults );

		$style = 'style="display: none;"';
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php esc_html_e( 'Title', 'rock-star-pro' ); ?>:</label>
			<input type="text" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" class="widefat" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'description' ); ?>"><?php esc_html_e( 'Description', 'rock-star-pro' ); ?>:</label>
			<textarea class="ct-textarea" name="<?php echo $this->get_field_name('description' ); ?>" id="<?php echo $this->get_field_id('description' ); ?>"><?php echo esc_textarea( $instance['description'] ) ?></textarea>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'post_type' ); ?>"><?php esc_html_e( 'Select Posts/Pages From', 'rock-star-pro' ); ?>:</label>
			<select class="ct_feat_post_post_type widefat" id="<?php echo $this->get_field_id( 'post_type' ); ?>" name="<?php echo $this->get_field_name( 'post_type' ); ?>">
				<?php
					$post_type_choices = array(
						'all-categories'  => esc_html__( 'Latest Post from all categories', 'rock-star-pro' ),
						'select-category' => esc_html__( 'Latest Posts from selected categories', 'rock-star-pro' ),
						'page'           => esc_html__( 'Latest Pages', 'rock-star-pro' ),
						'any'             => esc_html__( 'Latest Posts & Pages', 'rock-star-pro' ),
						'id'              => esc_html__( 'Featured Post/Page IDs', 'rock-star-pro' ),
					);

				foreach ( $post_type_choices as $key => $value ) {
					echo '<option value="' . $key . '" '. selected( $key, $instance['post_type'], false ) .'>' . $value .'</option>';
				}
				?>
			</select>
		</p>

		<p <?php echo ( 'id' == $instance['post_type'] )? '' : $style;  ?>>
			<label for="<?php echo $this->get_field_id( 'post_id' ); ?>"><?php esc_html_e( 'Post ID', 'rock-star-pro' ); ?>:</label>
			<input type="text" id="<?php echo $this->get_field_id( 'post_id' ); ?>" name="<?php echo $this->get_field_name( 'post_id' ); ?>" value="<?php echo sanitize_text_field( $instance['post_id'] ); ?>" class="widefat"/>
			<span class="ct-description"><?php esc_html_e( 'Separate Multiple Post/Page IDs by ,(comma)', 'rock-star-pro' ); ?></span>
		</p>

        <p <?php echo ( 'select-category' == $instance['post_type'] )? '': $style; ?>>
        	<?php
        		rock_star_dropdown_categories(
        			$this->get_field_name( 'category[]' ),
        			$this->get_field_id( 'category' ),
        			(array) $instance['category']
        		);
        	?>
        </p>

        <p <?php echo ( 'id' == $instance['post_type'] )? $style : '';  ?>>
			<label for="<?php echo $this->get_field_id( 'post_number' ); ?>"><?php esc_html_e( 'No. of Posts', 'rock-star-pro' ); ?>:</label>
			<input type="number" id="<?php echo $this->get_field_id( 'post_number' ); ?>" name="<?php echo $this->get_field_name( 'post_number' ); ?>" value="<?php echo absint( $instance['post_number'] ); ?>" class="small-text" min="1" />
		</p>

		<p>
            <label for="<?php echo $this->get_field_id( 'background-image' ); ?>"><?php esc_html_e( 'Background Image Url:','rock-star-pro'); ?></label>
            <br>
        	<input type="text" class="ct-upload" name="<?php echo $this->get_field_name( 'background-image' ); ?>" value="<?php echo esc_attr( $instance['background-image'] ); ?>" id="<?php echo $this->get_field_id( 'background-image' ); ?>" />
        	<button class="upload-media-button button button-primary"><?php esc_html_e( 'Upload', 'rock-star-pro' ); ?></button>
        </p>

        <p>
			<label for="<?php echo $this->get_field_id( 'layout' ); ?>"><?php esc_html_e( 'Layout', 'rock-star-pro' ); ?>:</label>
			<select id="<?php echo $this->get_field_id( 'layout' ); ?>" name="<?php echo $this->get_field_name( 'layout' ); ?>" class="widefat">
				<?php
					$post_type_choices = array(
						'video-grid-layout' => esc_html__( 'Grid Layout', 'rock-star-pro' ),
						'one-column'        => esc_html__( '1 Column', 'rock-star-pro' ),
						'two-columns'       => esc_html__( '2 Columns', 'rock-star-pro' ),
						'three-columns'     => esc_html__( '3 Columns', 'rock-star-pro' ),
						'four-columns'      => esc_html__( '4 Columns', 'rock-star-pro' ),
						'five-columns'      => esc_html__( '5 Columns', 'rock-star-pro' ),
					);

				foreach ( $post_type_choices as $key => $value ) {
					echo '<option value="' . $key . '" '. selected( $key, $instance['layout'], false ) .'>' . $value .'</option>';
				}
				?>
			</select>
		</p>

		<p>
        	<label for="<?php echo $this->get_field_id( 'link' ); ?>">
        		<?php echo esc_html__( 'Link', 'rock-star-pro' ); ?>
        	</label>
        	<input type="text" class="widefat" name="<?php echo $this->get_field_name('link'); ?>" id="<?php echo $this->get_field_id('link'); ?>" value="<?php echo esc_url( $instance['link'] ) ; ?>">
        </p>

        <p>
        	<label for="<?php echo $this->get_field_id( 'link_text' ); ?>">
        		<?php echo esc_html__( 'Link Text', 'rock-star-pro' ); ?>
        	</label>
        	<input type="text" class="widefat" name="<?php echo $this->get_field_name('link_text'); ?>" id="<?php echo $this->get_field_id('link_text'); ?>" value="<?php echo esc_attr( $instance['link_text'] ) ; ?>">
        </p>

		<p>
            <input class="checkbox" type="checkbox" <?php checked($instance['target'], true) ?> id="<?php echo $this->get_field_id( 'target' ); ?>" name="<?php echo $this->get_field_name( 'target' ); ?>" />
        	<label for="<?php echo $this->get_field_id('target'); ?>"><?php esc_html_e( 'Check to open link in new tab/window', 'rock-star-pro' ); ?></label><br />
        </p>

		<script>
		jQuery(document).ready(function($){
			post_type = $( '.ct_feat_post_post_type' );

			post_type.change(function(){
				post_type_val = $(this).val();
				post_id      = $(this).parent().next();
				multi_cat_id = $(this).parent().next().next();
				post_no_id   = $(this).parent().next().next().next();

				if ( 'all-categories' == post_type_val ) {
					post_id.hide();
					multi_cat_id.hide();
					post_no_id.show();
				}
				else if ( 'id' == post_type_val ) {
					post_id.show();
					multi_cat_id.hide();
					post_no_id.hide();
				}
				else if ( 'select-category' == post_type_val ) {
					post_id.hide();
					multi_cat_id.show();
					post_no_id.show();
				}else{
					post_id.hide();
					multi_cat_id.hide();
					post_no_id.show();
				}
				return false;
			});

		});
		</script>
       	<?php
	}

	function update( $new_instance, $old_instance ) {

		$instance                     = $old_instance;
		$instance['title']            = sanitize_text_field( $new_instance['title'] );
		$instance['description']      = wp_kses_post( $new_instance['description'] );
		$instance['post_type']        = sanitize_key( $new_instance['post_type'] );
		$instance['post_id']          = sanitize_text_field( $new_instance['post_id'] );
		$instance['category']         = ( array ) $new_instance['category'];
		$instance['post_number']      = absint( $new_instance['post_number'] );
		$instance['background-image'] = esc_url_raw( $new_instance['background-image'] );
		$instance['layout']           = sanitize_key( $new_instance['layout'] );
		$instance['link']             = esc_url_raw( $new_instance['link'] );
		$instance['link_text']        = sanitize_text_field( $new_instance['link_text'] );
		$instance['target']           = rock_star_sanitize_checkbox( $new_instance['target'] );

		return $instance;
	}

	function widget( $args, $instance ) {
		// Merge with defaults
		$instance = wp_parse_args( (array) $instance, $this->defaults );

		echo $args['before_widget'];

		// Display Widget Title
		if ( ! empty( $instance['title'] ) ) {
			echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base ) . $args['after_title'];
		}

		// Display Widget Description
		if ( ! empty( $instance['description'] ) ) {
			echo '<p>' . $instance['description'] . '</p>';
		}

		$query_args = array(
			'ignore_sticky_posts' => '1',
		);

		$post_type = 'post';
		if ( 'page' == $instance['post_type'] ) {
			$query_args['post_type'] = 'page';
		}else if ( 'any' == $instance['post_type'] || 'id' == $instance['post_type'] ) {
			$query_args['post_type'] = 'any';
		}

		if ( 'id' == $instance['post_type'] ) {
			$post_id_array = explode( ',', $instance['post_id'] );
			$query_args['post__in'] = $post_id_array;
		}
		else if ( 'select-category' == $instance['post_type'] ) {
			$query_args['category__in']    = ( array ) $instance['category'];
			$query_args['posts_per_page'] = absint( $instance['post_number'] );
		}
		else {
			$query_args['posts_per_page'] = absint( $instance['post_number'] );
		}

		$loop = new WP_Query( $query_args );

		$i = 0;

		if ( $loop->have_posts() ) :
			echo '<div class="article-wrap columns ' . esc_attr( $instance['layout'] ) . '">';
				while ( $loop->have_posts() ) : $loop->the_post();

					$class = 'post-'. esc_attr( get_the_ID() ) . ' post type-post hentry ';
		?>
			<article class="<?php echo $class; ?>">
				<div class="entry-container">
					<?php the_content(); ?>
				</div><!-- .entry-container -->
			</article>
		<?php

					$i++;

				endwhile;
			echo '</div><!-- .entry-content -->';

			$target = '_self';

			if ( isset( $instance['target'] ) && $instance['target'] ) {
				$target = '_blank';
			}

			if ( !empty( $instance['link'] ) && !empty( $instance['link_text'] ) ) {
				echo '<div class="view-more aligncenter">
	                            <a target="' . $target. '" href="' . esc_url( $instance['link'] ) . '">' . esc_html( $instance['link_text'] ) . '</a>
	                        </div><!-- end view more -->';
			}
		endif;

		//* Restore original query
		wp_reset_postdata();

		echo $args['after_widget'];

		if ( '' != $instance['background-image'] ) {
			echo '
			<style type="text/css" rel="ct-widget-css '. esc_attr( $args['widget_id'] ) .'">
				#'. esc_attr( $args['widget_id'] ) .' {
					background-image: url('. esc_url( $instance['background-image'] ) .');
					background-position: 50% 50%;
				}
			</style>'
			;
		}

	}
}

/**
 * Initialize Widget
 */
function rock_star_video_post_page_init() {
	register_widget( 'rock_star_video_post_page_widget' );
}
add_action( 'widgets_init', 'rock_star_video_post_page_init' );

